"""

This is Fishconsole Project

----

----
Fishconsole Project
----

- 我利用了几乎所有的业余时间设计了Fishconsole Project，虽然现在十分拉跨，但正努力前行

- 它是第一个使用中文变量的一个针对控制台输出的一个不断完善的工具集合

- 导入的语法是from Fishconsole import （你需要的模块），由python3.8.8编写，随心更新，长期项目

- 我只是个职高的高一学生，做的东西可能不会考虑的很周到，不喜勿喷

----

----
🦈Fishconsole 小鱼控制台功能一览
----

- LOGS模块

----

原生控制台指定文字的颜色修改

可以染色的分割线

可以染色的日志输出

可以染色的input输入加强

<还有很多>

- EASYGUI中文模块（WINDOW）

----

弹出窗口

文件选择

<还有很多>

- MATPLOTLIB中文模块（HUITU）

----

饼图，条形图，折线图，子图

<还有很多>

- 核心模块（FISHSYS）

----

加解密

“批量”下载网易云上的音乐

排名

检测文件存在情况

配置存储器

文本转str类型的Unicode

----

"""







__all__ = ["files","logs", "window", "helps", "fcv", "huitu", "Fishsys","Fishconsole_version_a","Fishconsole_version_a","houtai"]

def Fishconsole_project():
    from Fishconsole import fcv
    fcv.f_debug()


